# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Compute(_OpenStack):
    _type = "compute"
    _icon_dir = "resources/openstack/compute"


class Nova(_Compute):
    _icon = "nova.png"


class Qinling(_Compute):
    _icon = "qinling.png"


class Zun(_Compute):
    _icon = "zun.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _Network(_GCP):
    _type = "network"
    _icon_dir = "resources/gcp/network"


class Armor(_Network):
    _icon = "armor.png"


class CDN(_Network):
    _icon = "cdn.png"


class DedicatedInterconnect(_Network):
    _icon = "dedicated-interconnect.png"


class DNS(_Network):
    _icon = "dns.png"


class ExternalIpAddresses(_Network):
    _icon = "external-ip-addresses.png"


class FirewallRules(_Network):
    _icon = "firewall-rules.png"


class LoadBalancing(_Network):
    _icon = "load-balancing.png"


class NAT(_Network):
    _icon = "nat.png"


class Network(_Network):
    _icon = "network.png"


class PartnerInterconnect(_Network):
    _icon = "partner-interconnect.png"


class PremiumNetworkTier(_Network):
    _icon = "premium-network-tier.png"


class Router(_Network):
    _icon = "router.png"


class Routes(_Network):
    _icon = "routes.png"


class StandardNetworkTier(_Network):
    _icon = "standard-network-tier.png"


class TrafficDirector(_Network):
    _icon = "traffic-director.png"


class VirtualPrivateCloud(_Network):
    _icon = "virtual-private-cloud.png"


class VPN(_Network):
    _icon = "vpn.png"


# Aliases

VPC = VirtualPrivateCloud



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Device(_Generic):
    _type = "device"
    _icon_dir = "resources/generic/device"


class Mobile(_Device):
    _icon = "mobile.png"


class Tablet(_Device):
    _icon = "tablet.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Client(_OnPrem):
    _type = "client"
    _icon_dir = "resources/onprem/client"


class Client(_Client):
    _icon = "client.png"


class User(_Client):
    _icon = "user.png"


class Users(_Client):
    _icon = "users.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Devops(_OCI):
    _type = "devops"
    _icon_dir = "resources/oci/devops"


class APIGatewayWhite(_Devops):
    _icon = "api-gateway-white.png"


class APIGateway(_Devops):
    _icon = "api-gateway.png"


class APIServiceWhite(_Devops):
    _icon = "api-service-white.png"


class APIService(_Devops):
    _icon = "api-service.png"


class ResourceMgmtWhite(_Devops):
    _icon = "resource-mgmt-white.png"


class ResourceMgmt(_Devops):
    _icon = "resource-mgmt.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Rbac(_K8S):
    _type = "rbac"
    _icon_dir = "resources/k8s/rbac"


class CRole(_Rbac):
    _icon = "c-role.png"


class CRB(_Rbac):
    _icon = "crb.png"


class Group(_Rbac):
    _icon = "group.png"


class RB(_Rbac):
    _icon = "rb.png"


class Role(_Rbac):
    _icon = "role.png"


class SA(_Rbac):
    _icon = "sa.png"


class User(_Rbac):
    _icon = "user.png"


# Aliases

ClusterRole = CRole
ClusterRoleBinding = CRB
RoleBinding = RB
ServiceAccount = SA



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Billing(_OpenStack):
    _type = "billing"
    _icon_dir = "resources/openstack/billing"


class Cloudkitty(_Billing):
    _icon = "cloudkitty.png"


# Aliases

CloudKitty = Cloudkitty



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _IBM


class _Security(_IBM):
    _type = "security"
    _icon_dir = "resources/ibm/security"


class ApiSecurity(_Security):
    _icon = "api-security.png"


class BlockchainSecurityService(_Security):
    _icon = "blockchain-security-service.png"


class DataSecurity(_Security):
    _icon = "data-security.png"


class Firewall(_Security):
    _icon = "firewall.png"


class Gateway(_Security):
    _icon = "gateway.png"


class GovernanceRiskCompliance(_Security):
    _icon = "governance-risk-compliance.png"


class IdentityAccessManagement(_Security):
    _icon = "identity-access-management.png"


class IdentityProvider(_Security):
    _icon = "identity-provider.png"


class InfrastructureSecurity(_Security):
    _icon = "infrastructure-security.png"


class PhysicalSecurity(_Security):
    _icon = "physical-security.png"


class SecurityMonitoringIntelligence(_Security):
    _icon = "security-monitoring-intelligence.png"


class SecurityServices(_Security):
    _icon = "security-services.png"


class TrustendComputing(_Security):
    _icon = "trustend-computing.png"


class Vpn(_Security):
    _icon = "vpn.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Clusterconfig(_K8S):
    _type = "clusterconfig"
    _icon_dir = "resources/k8s/clusterconfig"


class HPA(_Clusterconfig):
    _icon = "hpa.png"


class Limits(_Clusterconfig):
    _icon = "limits.png"


class Quota(_Clusterconfig):
    _icon = "quota.png"


# Aliases

LimitRange = Limits
HorizontalPodAutoscaler = HPA



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _DigitalOcean


class _Database(_DigitalOcean):
    _type = "database"
    _icon_dir = "resources/digitalocean/database"


class DbaasPrimaryStandbyMore(_Database):
    _icon = "dbaas-primary-standby-more.png"


class DbaasPrimary(_Database):
    _icon = "dbaas-primary.png"


class DbaasReadOnly(_Database):
    _icon = "dbaas-read-only.png"


class DbaasStandby(_Database):
    _icon = "dbaas-standby.png"


# Aliases



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['diagrams',
 'diagrams.alibabacloud',
 'diagrams.aws',
 'diagrams.azure',
 'diagrams.base',
 'diagrams.custom',
 'diagrams.digitalocean',
 'diagrams.elastic',
 'diagrams.firebase',
 'diagrams.gcp',
 'diagrams.generic',
 'diagrams.ibm',
 'diagrams.k8s',
 'diagrams.oci',
 'diagrams.onprem',
 'diagrams.openstack',
 'diagrams.outscale',
 'diagrams.programming',
 'diagrams.saas']

package_data = \
{'': ['*']}

install_requires = \
['graphviz>=0.13.2,<0.20.0', 'jinja2>=2.10,<4.0']

extras_require = \
{':python_version >= "3.6" and python_version < "3.7"': ['contextvars>=2.4,<3.0']}

setup_kwargs = {
    'name': 'diagrams',
    'version': '0.21.1',
    'description': 'Diagram as Code',
    'long_description': '![diagrams logo](assets/img/diagrams.png)\n\n# Diagrams\n\n[![license](https://img.shields.io/badge/license-MIT-blue.svg)](/LICENSE)\n[![pypi version](https://badge.fury.io/py/diagrams.svg)](https://badge.fury.io/py/diagrams)\n![python version](https://img.shields.io/badge/python-%3E%3D%203.6-blue?logo=python)\n![Run tests](https://github.com/mingrammer/diagrams/workflows/Run%20tests/badge.svg?branch=master)\n[![todos](https://badgen.net/https/api.tickgit.com/badgen/github.com/mingrammer/diagrams?label=todos)](https://www.tickgit.com/browse?repo=github.com/mingrammer/diagrams)\n![contributors](https://img.shields.io/github/contributors/mingrammer/diagrams)\n\n<a href="https://www.buymeacoffee.com/mingrammer" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: 41px !important;width: 174px !important;box-shadow: 0px 3px 2px 0px rgba(190, 190, 190, 0.5) !important;" ></a>\n\n**Diagram as Code**.\n\nDiagrams lets you draw the cloud system architecture **in Python code**. It was born for **prototyping** a new system architecture design without any design tools. You can also describe or visualize the existing system architecture as well. Diagrams currently supports main major providers including: `AWS`, `Azure`, `GCP`, `Kubernetes`, `Alibaba Cloud`, `Oracle Cloud` etc... It also supports `On-Premise` nodes, `SaaS` and major `Programming` frameworks and languages.\n\n**Diagram as Code** also allows you to **track** the architecture diagram changes in any **version control** system.\n\n>  NOTE: It does not control any actual cloud resources nor does it generate cloud formation or terraform code. It is just for drawing the cloud system architecture diagrams.\n\n## Providers\n\n![aws provider](https://img.shields.io/badge/AWS-orange?logo=amazon-aws&color=ff9900)\n![azure provider](https://img.shields.io/badge/Azure-orange?logo=microsoft-azure&color=0089d6)\n![gcp provider](https://img.shields.io/badge/GCP-orange?logo=google-cloud&color=4285f4)\n![ibm provider](https://img.shields.io/badge/IBM-orange?logo=ibm&color=052FAD)\n![kubernetes provider](https://img.shields.io/badge/Kubernetes-orange?logo=kubernetes&color=326ce5)\n![alibaba cloud provider](https://img.shields.io/badge/AlibabaCloud-orange?logo=alibaba-cloud&color=ff6a00)\n![oracle cloud provider](https://img.shields.io/badge/OracleCloud-orange?logo=oracle&color=f80000)\n![openstack provider](https://img.shields.io/badge/OpenStack-orange?logo=openstack&color=da1a32)\n![firebase provider](https://img.shields.io/badge/Firebase-orange?logo=firebase&color=FFCA28)\n![digital ocean provider](https://img.shields.io/badge/DigitalOcean-0080ff?logo=digitalocean&color=0080ff)\n![elastic provider](https://img.shields.io/badge/Elastic-orange?logo=elastic&color=005571)\n![outscale provider](https://img.shields.io/badge/OutScale-orange?color=5f87bf)\n![on premise provider](https://img.shields.io/badge/OnPremise-orange?color=5f87bf)\n![generic provider](https://img.shields.io/badge/Generic-orange?color=5f87bf)\n![programming provider](https://img.shields.io/badge/Programming-orange?color=5f87bf)\n![saas provider](https://img.shields.io/badge/SaaS-orange?color=5f87bf)\n\n## Getting Started\n\nIt requires **Python 3.6** or higher, check your Python version first.\n\nIt uses [Graphviz](https://www.graphviz.org/) to render the diagram, so you need to [install Graphviz](https://graphviz.gitlab.io/download/) to use **diagrams**. After installing graphviz (or already have it), install the **diagrams**.\n\n> macOS users can download the Graphviz via `brew install graphviz` if you\'re using [Homebrew](https://brew.sh).\n\n```shell\n# using pip (pip3)\n$ pip install diagrams\n\n# using pipenv\n$ pipenv install diagrams\n\n# using poetry\n$ poetry add diagrams\n```\n\nYou can start with [quick start](https://diagrams.mingrammer.com/docs/getting-started/installation#quick-start). Check out [guides](https://diagrams.mingrammer.com/docs/guides/diagram) for more details, and you can find all available nodes list in [here](https://diagrams.mingrammer.com/docs/nodes/aws).\n\n## Examples\n\n| Event Processing                                             | Stateful Architecture                                        | Advanced Web Service                                         |\n| ------------------------------------------------------------ | ------------------------------------------------------------ | ------------------------------------------------------------ |\n| ![event processing](https://diagrams.mingrammer.com/img/event_processing_diagram.png) | ![stateful architecture](https://diagrams.mingrammer.com/img/stateful_architecture_diagram.png) | ![advanced web service with on-premise](https://diagrams.mingrammer.com/img/advanced_web_service_with_on-premise.png) |\n\nYou can find all the examples on the [examples](https://diagrams.mingrammer.com/docs/getting-started/examples) page.\n\n## Contributing\n\nTo contribute to diagram, check out [contribution guidelines](CONTRIBUTING.md).\n\n> Let me know if you are using diagrams! I\'ll add you in showcase page. (I\'m working on it!) :)\n\n## Who uses it?\n\n[GitPitch](https://gitpitch.github.io/gitpitch) is the perfect slide deck solution for Tech Conferences, Training, Developer Advocates, and Educators. Diagrams is now available as a dedicated [Cloud Diagram Markdown Widget](https://gitpitch.github.io/gitpitch/#/diagrams/cloud-architecture) so you can use Diagrams directly on any slide for conferences, meetups, and training.\n\n[Cloudiscovery](https://github.com/Cloud-Architects/cloudiscovery) helps you to analyze resources in your cloud (AWS/GCP/Azure/Alibaba/IBM) account. It allows you to create a diagram of analyzed cloud resource map based on this Diagrams library, so you can draw your existing cloud infrastructure with Cloudiscovery.\n\n[Airflow Diagrams](https://github.com/feluelle/airflow-diagrams) is an Airflow plugin that aims to easily visualise your Airflow DAGs on service level from providers like AWS, GCP, Azure, etc. via diagrams.\n\n## Other languages\n\n- If you are familiar to Go, you can use [go-diagrams](https://github.com/blushft/go-diagrams) as well.\n\n## License\n\n[MIT](LICENSE)\n',
    'author': 'mingrammer',
    'author_email': 'mingrammer@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://diagrams.mingrammer.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Azure


class _General(_Azure):
    _type = "general"
    _icon_dir = "resources/azure/general"


class Allresources(_General):
    _icon = "allresources.png"


class Azurehome(_General):
    _icon = "azurehome.png"


class Developertools(_General):
    _icon = "developertools.png"


class Helpsupport(_General):
    _icon = "helpsupport.png"


class Information(_General):
    _icon = "information.png"


class Managementgroups(_General):
    _icon = "managementgroups.png"


class Marketplace(_General):
    _icon = "marketplace.png"


class Quickstartcenter(_General):
    _icon = "quickstartcenter.png"


class Recent(_General):
    _icon = "recent.png"


class Reservations(_General):
    _icon = "reservations.png"


class Resource(_General):
    _icon = "resource.png"


class Resourcegroups(_General):
    _icon = "resourcegroups.png"


class Servicehealth(_General):
    _icon = "servicehealth.png"


class Shareddashboard(_General):
    _icon = "shareddashboard.png"


class Subscriptions(_General):
    _icon = "subscriptions.png"


class Support(_General):
    _icon = "support.png"


class Supportrequests(_General):
    _icon = "supportrequests.png"


class Tag(_General):
    _icon = "tag.png"


class Tags(_General):
    _icon = "tags.png"


class Templates(_General):
    _icon = "templates.png"


class Twousericon(_General):
    _icon = "twousericon.png"


class Userhealthicon(_General):
    _icon = "userhealthicon.png"


class Usericon(_General):
    _icon = "usericon.png"


class Userprivacy(_General):
    _icon = "userprivacy.png"


class Userresource(_General):
    _icon = "userresource.png"


class Whatsnew(_General):
    _icon = "whatsnew.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Compute(_OCI):
    _type = "compute"
    _icon_dir = "resources/oci/compute"


class AutoscaleWhite(_Compute):
    _icon = "autoscale-white.png"


class Autoscale(_Compute):
    _icon = "autoscale.png"


class BMWhite(_Compute):
    _icon = "bm-white.png"


class BM(_Compute):
    _icon = "bm.png"


class ContainerWhite(_Compute):
    _icon = "container-white.png"


class Container(_Compute):
    _icon = "container.png"


class FunctionsWhite(_Compute):
    _icon = "functions-white.png"


class Functions(_Compute):
    _icon = "functions.png"


class InstancePoolsWhite(_Compute):
    _icon = "instance-pools-white.png"


class InstancePools(_Compute):
    _icon = "instance-pools.png"


class OCIRWhite(_Compute):
    _icon = "ocir-white.png"


class OCIR(_Compute):
    _icon = "ocir.png"


class OKEWhite(_Compute):
    _icon = "oke-white.png"


class OKE(_Compute):
    _icon = "oke.png"


class VMWhite(_Compute):
    _icon = "vm-white.png"


class VM(_Compute):
    _icon = "vm.png"


# Aliases

VirtualMachine = VM
VirtualMachineWhite = VMWhite
BareMetal = BM
BareMetalWhite = BMWhite
OCIRegistry = OCIR
OCIRegistryWhite = OCIRWhite
ContainerEngine = OKE
ContainerEngineWhite = OKEWhite



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Ci(_OnPrem):
    _type = "ci"
    _icon_dir = "resources/onprem/ci"


class Circleci(_Ci):
    _icon = "circleci.png"


class Concourseci(_Ci):
    _icon = "concourseci.png"


class Droneci(_Ci):
    _icon = "droneci.png"


class GithubActions(_Ci):
    _icon = "github-actions.png"


class Gitlabci(_Ci):
    _icon = "gitlabci.png"


class Jenkins(_Ci):
    _icon = "jenkins.png"


class Teamcity(_Ci):
    _icon = "teamcity.png"


class Travisci(_Ci):
    _icon = "travisci.png"


class Zuulci(_Ci):
    _icon = "zuulci.png"


# Aliases

CircleCI = Circleci
ConcourseCI = Concourseci
DroneCI = Droneci
GitlabCI = Gitlabci
TravisCI = Travisci
TC = Teamcity
ZuulCI = Zuulci



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Workflow(_OnPrem):
    _type = "workflow"
    _icon_dir = "resources/onprem/workflow"


class Airflow(_Workflow):
    _icon = "airflow.png"


class Digdag(_Workflow):
    _icon = "digdag.png"


class Kubeflow(_Workflow):
    _icon = "kubeflow.png"


class Nifi(_Workflow):
    _icon = "nifi.png"


# Aliases

KubeFlow = Kubeflow
NiFi = Nifi



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Vcs(_OnPrem):
    _type = "vcs"
    _icon_dir = "resources/onprem/vcs"


class Git(_Vcs):
    _icon = "git.png"


class Gitea(_Vcs):
    _icon = "gitea.png"


class Github(_Vcs):
    _icon = "github.png"


class Gitlab(_Vcs):
    _icon = "gitlab.png"


class Svn(_Vcs):
    _icon = "svn.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Satellite(_AWS):
    _type = "satellite"
    _icon_dir = "resources/aws/satellite"


class GroundStation(_Satellite):
    _icon = "ground-station.png"


class Satellite(_Satellite):
    _icon = "satellite.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Mlops(_OnPrem):
    _type = "mlops"
    _icon_dir = "resources/onprem/mlops"


class Polyaxon(_Mlops):
    _icon = "polyaxon.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Programming


class _Framework(_Programming):
    _type = "framework"
    _icon_dir = "resources/programming/framework"


class Angular(_Framework):
    _icon = "angular.png"


class Backbone(_Framework):
    _icon = "backbone.png"


class Django(_Framework):
    _icon = "django.png"


class Ember(_Framework):
    _icon = "ember.png"


class Fastapi(_Framework):
    _icon = "fastapi.png"


class Flask(_Framework):
    _icon = "flask.png"


class Flutter(_Framework):
    _icon = "flutter.png"


class Laravel(_Framework):
    _icon = "laravel.png"


class Micronaut(_Framework):
    _icon = "micronaut.png"


class Rails(_Framework):
    _icon = "rails.png"


class React(_Framework):
    _icon = "react.png"


class Spring(_Framework):
    _icon = "spring.png"


class Starlette(_Framework):
    _icon = "starlette.png"


class Vue(_Framework):
    _icon = "vue.png"


# Aliases

FastAPI = Fastapi



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Compute(_K8S):
    _type = "compute"
    _icon_dir = "resources/k8s/compute"


class Cronjob(_Compute):
    _icon = "cronjob.png"


class Deploy(_Compute):
    _icon = "deploy.png"


class DS(_Compute):
    _icon = "ds.png"


class Job(_Compute):
    _icon = "job.png"


class Pod(_Compute):
    _icon = "pod.png"


class RS(_Compute):
    _icon = "rs.png"


class STS(_Compute):
    _icon = "sts.png"


# Aliases

Deployment = Deploy
DaemonSet = DS
ReplicaSet = RS
StatefulSet = STS



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Monitoring(_OnPrem):
    _type = "monitoring"
    _icon_dir = "resources/onprem/monitoring"


class Cortex(_Monitoring):
    _icon = "cortex.png"


class Datadog(_Monitoring):
    _icon = "datadog.png"


class Dynatrace(_Monitoring):
    _icon = "dynatrace.png"


class Grafana(_Monitoring):
    _icon = "grafana.png"


class Humio(_Monitoring):
    _icon = "humio.png"


class Nagios(_Monitoring):
    _icon = "nagios.png"


class Newrelic(_Monitoring):
    _icon = "newrelic.png"


class PrometheusOperator(_Monitoring):
    _icon = "prometheus-operator.png"


class Prometheus(_Monitoring):
    _icon = "prometheus.png"


class Sentry(_Monitoring):
    _icon = "sentry.png"


class Splunk(_Monitoring):
    _icon = "splunk.png"


class Thanos(_Monitoring):
    _icon = "thanos.png"


class Zabbix(_Monitoring):
    _icon = "zabbix.png"


# Aliases



"""
AlibabaCloud provides a set of services for Alibaba Cloud provider.
"""

from diagrams import Node


class _AlibabaCloud(Node):
    _provider = "alibabacloud"
    _icon_dir = "resources/alibabacloud"

    fontcolor = "#ffffff"



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Programming


class _Language(_Programming):
    _type = "language"
    _icon_dir = "resources/programming/language"


class Bash(_Language):
    _icon = "bash.png"


class C(_Language):
    _icon = "c.png"


class Cpp(_Language):
    _icon = "cpp.png"


class Csharp(_Language):
    _icon = "csharp.png"


class Dart(_Language):
    _icon = "dart.png"


class Elixir(_Language):
    _icon = "elixir.png"


class Erlang(_Language):
    _icon = "erlang.png"


class Go(_Language):
    _icon = "go.png"


class Java(_Language):
    _icon = "java.png"


class Javascript(_Language):
    _icon = "javascript.png"


class Kotlin(_Language):
    _icon = "kotlin.png"


class Latex(_Language):
    _icon = "latex.png"


class Matlab(_Language):
    _icon = "matlab.png"


class Nodejs(_Language):
    _icon = "nodejs.png"


class Php(_Language):
    _icon = "php.png"


class Python(_Language):
    _icon = "python.png"


class R(_Language):
    _icon = "r.png"


class Ruby(_Language):
    _icon = "ruby.png"


class Rust(_Language):
    _icon = "rust.png"


class Scala(_Language):
    _icon = "scala.png"


class Swift(_Language):
    _icon = "swift.png"


class Typescript(_Language):
    _icon = "typescript.png"


# Aliases

JavaScript = Javascript
NodeJS = Nodejs
PHP = Php
TypeScript = Typescript



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Identity(_Saas):
    _type = "identity"
    _icon_dir = "resources/saas/identity"


class Auth0(_Identity):
    _icon = "auth0.png"


class Okta(_Identity):
    _icon = "okta.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Group(_K8S):
    _type = "group"
    _icon_dir = "resources/k8s/group"


class NS(_Group):
    _icon = "ns.png"


# Aliases

Namespace = NS



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Logging(_OnPrem):
    _type = "logging"
    _icon_dir = "resources/onprem/logging"


class Fluentbit(_Logging):
    _icon = "fluentbit.png"


class Graylog(_Logging):
    _icon = "graylog.png"


class Loki(_Logging):
    _icon = "loki.png"


class Rsyslog(_Logging):
    _icon = "rsyslog.png"


class SyslogNg(_Logging):
    _icon = "syslog-ng.png"


# Aliases

FluentBit = Fluentbit
RSyslog = Rsyslog



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Aggregator(_OnPrem):
    _type = "aggregator"
    _icon_dir = "resources/onprem/aggregator"


class Fluentd(_Aggregator):
    _icon = "fluentd.png"


class Vector(_Aggregator):
    _icon = "vector.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Outscale


class _Compute(_Outscale):
    _type = "compute"
    _icon_dir = "resources/outscale/compute"


class Compute(_Compute):
    _icon = "compute.png"


class DirectConnect(_Compute):
    _icon = "direct-connect.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _IBM


class _Applications(_IBM):
    _type = "applications"
    _icon_dir = "resources/ibm/applications"


class ActionableInsight(_Applications):
    _icon = "actionable-insight.png"


class Annotate(_Applications):
    _icon = "annotate.png"


class ApiDeveloperPortal(_Applications):
    _icon = "api-developer-portal.png"


class ApiPolyglotRuntimes(_Applications):
    _icon = "api-polyglot-runtimes.png"


class AppServer(_Applications):
    _icon = "app-server.png"


class ApplicationLogic(_Applications):
    _icon = "application-logic.png"


class EnterpriseApplications(_Applications):
    _icon = "enterprise-applications.png"


class Index(_Applications):
    _icon = "index.png"


class IotApplication(_Applications):
    _icon = "iot-application.png"


class Microservice(_Applications):
    _icon = "microservice.png"


class MobileApp(_Applications):
    _icon = "mobile-app.png"


class Ontology(_Applications):
    _icon = "ontology.png"


class OpenSourceTools(_Applications):
    _icon = "open-source-tools.png"


class RuntimeServices(_Applications):
    _icon = "runtime-services.png"


class SaasApplications(_Applications):
    _icon = "saas-applications.png"


class ServiceBroker(_Applications):
    _icon = "service-broker.png"


class SpeechToText(_Applications):
    _icon = "speech-to-text.png"


class VisualRecognition(_Applications):
    _icon = "visual-recognition.png"


class Visualization(_Applications):
    _icon = "visualization.png"


# Aliases



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _IBM


class _Data(_IBM):
    _type = "data"
    _icon_dir = "resources/ibm/data"


class Caches(_Data):
    _icon = "caches.png"


class Cloud(_Data):
    _icon = "cloud.png"


class ConversationTrainedDeployed(_Data):
    _icon = "conversation-trained-deployed.png"


class DataServices(_Data):
    _icon = "data-services.png"


class DataSources(_Data):
    _icon = "data-sources.png"


class DeviceIdentityService(_Data):
    _icon = "device-identity-service.png"


class DeviceRegistry(_Data):
    _icon = "device-registry.png"


class EnterpriseData(_Data):
    _icon = "enterprise-data.png"


class EnterpriseUserDirectory(_Data):
    _icon = "enterprise-user-directory.png"


class FileRepository(_Data):
    _icon = "file-repository.png"


class GroundTruth(_Data):
    _icon = "ground-truth.png"


class Model(_Data):
    _icon = "model.png"


class TmsDataInterface(_Data):
    _icon = "tms-data-interface.png"


# Aliases



"""
Firebase provides a set of services for Firebase provider.
"""

from diagrams import Node


class _Firebase(Node):
    _provider = "firebase"
    _icon_dir = "resources/firebase"

    fontcolor = "#ffffff"



# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Firebase


class _Develop(_Firebase):
    _type = "develop"
    _icon_dir = "resources/firebase/develop"


class Authentication(_Develop):
    _icon = "authentication.png"


class Firestore(_Develop):
    _icon = "firestore.png"


class Functions(_Develop):
    _icon = "functions.png"


class Hosting(_Develop):
    _icon = "hosting.png"


class MLKit(_Develop):
    _icon = "ml-kit.png"


class RealtimeDatabase(_Develop):
    _icon = "realtime-database.png"


class Storage(_Develop):
    _icon = "storage.png"


# Aliases



"""
DigitalOcean provides a set of services for DigitalOcean provider.
"""

from diagrams import Node


class _DigitalOcean(Node):
    _provider = "digitalocean"
    _icon_dir = "resources/digitalocean"

    fontcolor = "#ffffff"
